@@ -2,22 +2,9 @@
  *  alarmtext.h  -  text/email alarm text conversion
  *  This file is part of kalarmcal library, which provides access to KAlarm
  *  calendar data.
- *  Copyright © 2004-2019 David Jarvie <djarvie@kde.org>
+ *  SPDX-FileCopyrightText: 2004-2020 David Jarvie <djarvie@kde.org>
  *
- *  This library is free software; you can redistribute it and/or modify
- *  it under the terms of the GNU Library General Public License as published
- *  by the Free Software Foundation; either version 2 of the License, or (at
- *  your option) any later version.
- *
- *  This library is distributed in the hope that it will be useful, but WITHOUT
- *  ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
- *  FITNESS FOR A PARTICULAR PURPOSE.  See the GNU Library General Public
- *  License for more details.
- *
- *  You should have received a copy of the GNU Library General Public License
- *  along with this library; see the file COPYING.LIB.  If not, write to the
- *  Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston,
- *  MA 02110-1301, USA.
+ *  SPDX-License-Identifier: LGPL-2.0-or-later
  */
 
 #ifndef KALARM_ALARMTEXT_H
@@ -25,8 +12,8 @@
 
 #include "kalarmcal_export.h"
 
-#include <kcalendarcore/todo.h>
-#include <AkonadiCore/item.h>
+#include <KCalendarCore/Todo>
+#include <AkonadiCore/Item>
 #include <QString>
 
 namespace KAlarmCal
@@ -61,6 +48,9 @@ public:
     ~AlarmText();
     AlarmText &operator=(const AlarmText &other);
 
+    /** Initialise the instance to an empty state. */
+    void clear();
+
     /** Set the alarm text.
      *  If @p text starts with '#!', it is flagged as a script, else plain text.
      *  @param text alarm text to set
