@@ -2,22 +2,9 @@
  *  kacalendar.cpp  -  KAlarm kcal library calendar and event functions
  *  This file is part of kalarmcal library, which provides access to KAlarm
  *  calendar data.
- *  Copyright © 2001-2019 David Jarvie <djarvie@kde.org>
+ *  SPDX-FileCopyrightText: 2001-2020 David Jarvie <djarvie@kde.org>
  *
- *  This library is free software; you can redistribute it and/or modify
- *  it under the terms of the GNU Library General Public License as published
- *  by the Free Software Foundation; either version 2 of the License, or (at
- *  your option) any later version.
- *
- *  This library is distributed in the hope that it will be useful, but WITHOUT
- *  ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
- *  FITNESS FOR A PARTICULAR PURPOSE.  See the GNU Library General Public
- *  License for more details.
- *
- *  You should have received a copy of the GNU Library General Public License
- *  along with this library; see the file COPYING.LIB.  If not, write to the
- *  Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston,
- *  MA 02110-1301, USA.
+ *  SPDX-License-Identifier: LGPL-2.0-or-later
  */
 
 #include "kacalendar.h"
@@ -25,9 +12,9 @@
 #include "kaevent.h"
 #include "version.h"
 
-#include <kcalendarcore/event.h>
-#include <kcalendarcore/alarm.h>
-#include <kcalendarcore/memorycalendar.h>
+#include <KCalendarCore/Event>
+#include <KCalendarCore/Alarm>
+#include <KCalendarCore/MemoryCalendar>
 
 #include <klocalizedstring.h>
 #include "kalarmcal_debug.h"
@@ -457,4 +444,17 @@ QStringList mimeTypes(Types types)
 
 } // namespace KAlarmCal
 
+QDebug operator<<(QDebug debug, KAlarmCal::CalEvent::Type type)
+{
+    const char* str;
+    switch (type) {
+    case KAlarmCal::CalEvent::ACTIVE:    str = "Active alarms";    break;
+    case KAlarmCal::CalEvent::ARCHIVED:  str = "Archived alarms";  break;
+    case KAlarmCal::CalEvent::TEMPLATE:  str = "Alarm templates";  break;
+    default:        return debug;
+    }
+    debug << str;
+    return debug;
+}
+
 // vim: et sw=4:
