@@ -2,22 +2,9 @@
  *  kaevent.h  -  represents calendar events
  *  This file is part of kalarmcal library, which provides access to KAlarm
  *  calendar data.
- *  Copyright © 2001-2019 David Jarvie <djarvie@kde.org>
+ *  SPDX-FileCopyrightText: 2001-2019 David Jarvie <djarvie@kde.org>
  *
- *  This library is free software; you can redistribute it and/or modify
- *  it under the terms of the GNU Library General Public License as published
- *  by the Free Software Foundation; either version 2 of the License, or (at
- *  your option) any later version.
- *
- *  This library is distributed in the hope that it will be useful, but WITHOUT
- *  ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
- *  FITNESS FOR A PARTICULAR PURPOSE.  See the GNU Library General Public
- *  License for more details.
- *
- *  You should have received a copy of the GNU Library General Public License
- *  along with this library; see the file COPYING.LIB.  If not, write to the
- *  Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston,
- *  MA 02110-1301, USA.
+ *  SPDX-License-Identifier: LGPL-2.0-or-later
  */
 
 #ifndef KALARM_KAEVENT_H
@@ -32,8 +19,8 @@
 
 #include <collection.h>
 #include <item.h>
-#include <kcalendarcore/person.h>
-#include <kcalendarcore/calendar.h>
+#include <KCalendarCore/Person>
+#include <KCalendarCore/Calendar>
 #include <AkonadiCore/item.h>
 
 #include <QBitArray>
@@ -221,7 +208,8 @@ public:
                                    //!< if a holiday region has been set by setHolidays().
         WORK_TIME_ONLY  = 0x8000,  //!< trigger the alarm only during working hours
         DISPLAY_COMMAND = 0x10000, //!< display command output in the alarm window
-        REMINDER_ONCE   = 0x20000  //!< only trigger the reminder on the first recurrence
+        REMINDER_ONCE   = 0x20000, //!< only trigger the reminder on the first recurrence
+        DONT_SHOW_ERROR = 0x40000  //!< do not notify command alarm errors to user
 
                           // IMPORTANT: if any values are added to this list, ensure that the
                           //            additional enum values in KAEventPrivate are also adjusted.
@@ -360,8 +348,9 @@ public:
      *    set numerous KAEvent properties; non-KAlarm properties are simply stored.
      *  - Custom status if equal to "DISABLED".
      *  - Revision number.
+     *  @deprecated Use constructor and operator=() instead.
      */
-    void set(const KCalendarCore::Event::Ptr &);
+    KALARMCAL_DEPRECATED void set(const KCalendarCore::Event::Ptr &);
 
     KAEvent(const KAEvent &other);
     ~KAEvent();
@@ -384,8 +373,9 @@ public:
      *  @param changesPending true to inhibit automatic data updates until
      *                        further changes have been applied to the instance;
      *                        call endChanges() when changes are complete.
+     *  @deprecated Use constructor and operator=() instead.
      */
-    void set(const KADateTime &dt, const QString &text, const QColor &bg,
+    KALARMCAL_DEPRECATED void set(const KADateTime &dt, const QString &text, const QColor &bg,
              const QColor &fg, const QFont &font, SubAction action, int lateCancel,
              Flags flags, bool changesPending = false);
 
@@ -457,9 +447,24 @@ public:
     /** Return the revision number of the event (SEQUENCE property in iCalendar). */
     int revision() const;
 
-    /** Set the ID of the Akonadi Collection which contains the event. */
+    /** Set the ID of the Akonadi Collection which contains the event.
+     *  @see setResourceId() is the generic form of this method.
+     */
     void setCollectionId(Akonadi::Collection::Id id);
 
+    /** Set the ID of the calendar resource which contains the event. */
+    void setResourceId(ResourceId id);
+
+    /** Set the ID of the Akonadi Collection which contains the event.
+     *  @warning This is a const method, which means that any other instance
+     *           which references the same shared data will also be
+     *           updated. It is designed to be used when a KAEvent is
+     *           being created from an Akonadi Item, to avoid unnecessary
+     *           copying. Use with caution!
+     *  @see setResourceId_const() is the generic form of this method.
+     */
+    void setCollectionId_const(Akonadi::Collection::Id id) const;
+
     /** Set the ID of the Akonadi Collection which contains the event.
      *  @warning This is a const method, which means that any other instance
      *           which references the same shared data will also be
@@ -467,23 +472,33 @@ public:
      *           being created from an Akonadi Item, to avoid unnecessary
      *           copying. Use with caution!
      */
-    void setCollectionId_const(Akonadi::Collection::Id id) const;
+    void setResourceId_const(ResourceId id) const;
 
-    /** Return the ID of the Akonadi Collection which contains the event. */
+    /** Return the ID of the Akonadi Collection which contains the event.
+     *  @see resourceId() is the generic form of this method.
+     */
     Akonadi::Collection::Id  collectionId() const;
 
-    /** Set the ID of the Akonadi Item which contains the event. */
-    void setItemId(Akonadi::Item::Id id);
+    /** Return the ID of the calendar resource which contains the event. */
+    ResourceId  resourceId() const;
 
-    /** Return the ID of the Akonadi Item which contains the event. */
-    Akonadi::Item::Id  itemId() const;
+    /** Set the ID of the Akonadi Item which contains the event.
+     *  @deprecated KAlarmCal will no longer provide this functionality.
+     */
+    KALARMCAL_DEPRECATED void setItemId(Akonadi::Item::Id id);
+
+    /** Return the ID of the Akonadi Item which contains the event.
+     *  @deprecated KAlarmCal will no longer provide this functionality.
+     */
+    KALARMCAL_DEPRECATED Akonadi::Item::Id  itemId() const;
 
     /** Initialise an Akonadi::Item with the event's data.
      *  Note that the event is not updated with the Item ID.
      *  @return @c true if successful; @c false if the event's category does not match the
      *          collection's mime types.
+     *  @deprecated Use KAlarmCal::setItemPayload() instead.
      */
-    bool setItemPayload(Akonadi::Item &, const QStringList &collectionMimeTypes) const;
+    KALARMCAL_DEPRECATED bool setItemPayload(Akonadi::Item &, const QStringList &collectionMimeTypes) const;
 
     /** Note the event's storage format compatibility compared to the current KAlarm calendar format. */
     void setCompatibility(KACalendar::Compat c);
@@ -602,6 +617,11 @@ public:
     /** Return the command execution error for the last time the alarm triggered. */
     CmdErrType commandError() const;
 
+    /** Return whether execution errors for the command should not to be shown to the user.
+     *  @since 20.08
+     */
+    bool commandHideError() const;
+
     /** Set the log file to write command alarm output to.
      *  @param logfile  log file path
      */
@@ -1192,24 +1212,25 @@ public:
      *  saved in case their end time expires before the next login.
      *  @param event      the event to copy
      *  @param type       the alarm type (main, reminder, deferred etc.)
-     *  @param colId      the ID of the collection which originally contained the event
+     *  @param colId      the ID of the calendar resource which originally contained the event
      *  @param repeatAtLoginTime repeat-at-login time if @p type == AT_LOGIN_ALARM, else ignored
      *  @param showEdit   whether the Edit button was displayed
      *  @param showDefer  whether the Defer button was displayed
      *  @return @c true if successful, @c false if alarm was not copied.
      */
-    bool setDisplaying(const KAEvent &event, KAAlarm::Type type, Akonadi::Collection::Id colId, const KADateTime &repeatAtLoginTime, bool showEdit, bool showDefer);
+    bool setDisplaying(const KAEvent &event, KAAlarm::Type type, ResourceId colId, const KADateTime &repeatAtLoginTime, bool showEdit, bool showDefer);
 
     /** Reinstate the original event from the 'displaying' event.
      *  This instance is initialised from the supplied displaying @p event,
      *  and appropriate adjustments are made to convert it back to the
      *  original pre-displaying state.
      *  @param event      the displaying event
-     *  @param colId      updated to the ID of the collection which originally contained the event
+     *  @param colId      updated to the ID of the calendar resource which
+     *                    originally contained the event
      *  @param showEdit   updated to true if Edit button was displayed, else false
      *  @param showDefer  updated to true if Defer button was displayed, else false
      */
-    void reinstateFromDisplaying(const KCalendarCore::Event::Ptr &event, Akonadi::Collection::Id &colId, bool &showEdit, bool &showDefer);
+    void reinstateFromDisplaying(const KCalendarCore::Event::Ptr &event, ResourceId &colId, bool &showEdit, bool &showDefer);
 
     /** Return the original alarm which the displaying alarm refers to.
      *  Note that the caller is responsible for ensuring that the event was
@@ -1262,6 +1283,26 @@ public:
      */
     void removeExpiredAlarm(KAAlarm::Type type);
 
+    /** Data categories for compare(). */
+    enum class Compare {
+        Id           = 0x01,   //!< the event ID
+        ICalendar    = 0x02,   //!< extra event properties in the iCalendar file: custom properties, revision, creation timestamp
+        UserSettable = 0x04,   //!< user settable data: resource ID, item ID
+        CurrentState = 0x08    //!< changeable data which records the event's current state: next trigger time etc.
+    };
+    Q_DECLARE_FLAGS(Comparison, Compare)
+
+    /** Compare this instance with another.
+     *  All data which defines the characteristics of this event will be
+     *  compared, plus optional data categories as specified.
+     *  @param other       the other event to be compared.
+     *  @param comparison  the optional data categories to compare, in addition
+     *                     to the basic data. Other optional categories will be
+     *                     ignored in the comparison.
+     *  @return true if the instances match, false otherwise.
+     */
+    bool compare(const KAEvent& other, Comparison comparison) const;
+
     /** Call before making a group of changes to the event, to avoid unnecessary
      *  calculation intensive recalculations of trigger times from being
      *  performed until all the changes have been applied. When the changes
@@ -1318,6 +1359,7 @@ private:
 } // namespace KAlarmCal
 
 Q_DECLARE_OPERATORS_FOR_FLAGS(KAlarmCal::KAEvent::Flags)
+Q_DECLARE_OPERATORS_FOR_FLAGS(KAlarmCal::KAEvent::Comparison)
 Q_DECLARE_METATYPE(KAlarmCal::KAEvent)
 
 #endif // KALARM_KAEVENT_H
