@@ -2,22 +2,9 @@
  *  karecurrence.h  -  recurrence with special yearly February 29th handling
  *  This file is part of kalarmcal library, which provides access to KAlarm
  *  calendar data.
- *  Copyright © 2005-2012 David Jarvie <djarvie@kde.org>
+ *  SPDX-FileCopyrightText: 2005-2012 David Jarvie <djarvie@kde.org>
  *
- *  This library is free software; you can redistribute it and/or modify
- *  it under the terms of the GNU Library General Public License as published
- *  by the Free Software Foundation; either version 2 of the License, or (at
- *  your option) any later version.
- *
- *  This library is distributed in the hope that it will be useful, but WITHOUT
- *  ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
- *  FITNESS FOR A PARTICULAR PURPOSE.  See the GNU Library General Public
- *  License for more details.
- *
- *  You should have received a copy of the GNU Library General Public License
- *  along with this library; see the file COPYING.LIB.  If not, write to the
- *  Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston,
- *  MA 02110-1301, USA.
+ *  SPDX-License-Identifier: LGPL-2.0-or-later
  */
 
 #ifndef KALARM_KARECURRENCE_H
@@ -26,9 +13,9 @@
 #include "kalarmcal_export.h"
 #include "kadatetime.h"
 
-#include <kcalendarcore/recurrencerule.h>
-#include <kcalendarcore/duration.h>
-#include <kcalendarcore/incidencebase.h>
+#include <KCalendarCore/RecurrenceRule>
+#include <KCalendarCore/Duration>
+#include <KCalendarCore/IncidenceBase>
 namespace KCalendarCore
 {
 class Recurrence;
